intelmq.bots.experts.deduplicator package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.experts.deduplicator package

## Submodules

## intelmq.bots.experts.deduplicator.expert module

Deduplicator expert bot

param redis_cache_host

  string

param redis_cache_port

  int

param redis_cache_db

  int

param redis_cache_ttl

  int

param redis_cache_password

  string. default: {None}

param filter_type

  string [“blacklist”, “whitelist”]

param bypass

  boolean default: False

param filter_keys

  string with multiple keys separated by comma. Please note that time.observation key is never consider by the system because system will always ignore this key.

`intelmq.bots.experts.deduplicator.expert.` `BOT`

  alias of `intelmq.bots.experts.deduplicator.expert.DeduplicatorExpertBot`

class `intelmq.bots.experts.deduplicator.expert.` `DeduplicatorExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`, `intelmq.lib.mixins.cache.CacheMixin`

  Detection and drop exact duplicate messages. Message hashes are cached in the Redis database

  `bypass` = False
  `filter_keys`: str = None
  `filter_type`: str = 'blacklist'
  `init`()
  `process`()
  `redis_cache_db`: int = 6
  `redis_cache_host`: str = '127.0.0.1'
  `redis_cache_password`: str = None
  `redis_cache_port`: int = 6379
  `redis_cache_ttl`: int = 86400

## Module contents